@@ -9,5 +9,5 @@ urlpatterns = patterns('',
                        url(r'^categories/(?P<pk>[0-9]+)/$',
                            views.PriceCategoriesDetailsProxy.as_view(http_method_names=['get'])),
                        url(r'^orders/$', views.OrdersProxy.as_view(http_method_names=['post'])),
-                       url(r'^orders/(?P<pk>[0-9]+)/$', views.OrderDetailsProxy.as_view(http_method_names=['patch'])),
+                       url(r'^orders/(?P<pk>[0-9]+)/$', views.OrderDetailsProxy.as_view(http_method_names=['get'])),
                        )
